# CUDA_HYBRID

This repository contains the first ever ABM/FCM Hybrid Model on CUDA cores that can help run the simulation in parallel, 
reducing the runtime

## Requirements:
The project requires Python 3.7 or higher, depending on the version of the packages in `requirements.txt`.

## Installation

```bash
$ pip install cuda-hybrid
```

## Quick Start
### Import
```bash
from cuda_hybrid import cuda_hybrid
```